| ceil | R Documentation |
A ceiling function with a tolerance at the 13th digit
ceil(x, digits = 13)
x |
numeric, that needs |
digits |
integer, position of the digit to round of to |
integer
ceiling(27/21*21)
ceil(27/21*21)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.