checkAndReturnEsMinParameterSide: Checks consistency between the sided of the hypothesis and...

View source: R/helpers.R

checkAndReturnEsMinParameterSideR Documentation

Checks consistency between the sided of the hypothesis and the minimal clinically relevant effect size or savi test defining parameter. Throws an error if the one-sided hypothesis is incongruent with the

Description

Checks consistency between the sided of the hypothesis and the minimal clinically relevant effect size or savi test defining parameter. Throws an error if the one-sided hypothesis is incongruent with the

Usage

checkAndReturnEsMinParameterSide(
  paramToCheck,
  alternative = c("twoSided", "greater", "less"),
  esMinName = c("noName", "meanDiffMin", "meanDiffTrue", "phiS", "deltaMin", "deltaS",
    "hrMin", "thetaS", "deltaTrue", "g", "kappaG"),
  paramDomain = NULL
)

Arguments

paramToCheck

numeric. Either a named savi test defining parameter such as phiS, or thetaS, or a minimal clinically relevant effect size called with a non-null esMinName name

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less".

esMinName

provides the name of the effect size. Either "meanDiffMin" for the z-test, "deltaMin" for the t-test, or "hrMin" for the logrank test

paramDomain

Domain of the paramToCheck, typically, positiveNumbers. Default NULL

Value

paramToCheck after checking, perhaps with a change in sign


safestats documentation built on Sept. 6, 2026, 1:06 a.m.