Learn R Programming

safestats (version 0.8.7)

checkAndReturnsEsMinParameterSide: Checks consistency between the sided of the hypothesis and the minimal clinically relevant effect size or safe test defining parameter. Throws an error if the one-sided hypothesis is incongruent with the

Description

Checks consistency between the sided of the hypothesis and the minimal clinically relevant effect size or safe test defining parameter. Throws an error if the one-sided hypothesis is incongruent with the

Usage

checkAndReturnsEsMinParameterSide(
  paramToCheck,
  alternative = c("twoSided", "greater", "less"),
  esMinName = c("noName", "meanDiffMin", "phiS", "deltaMin", "deltaS", "hrMin", "thetaS",
    "deltaTrue"),
  paramDomain = NULL
)

Value

paramToCheck after checking, perhaps with a change in sign

Arguments

paramToCheck

numeric. Either a named safe test defining parameter such as phiS, or thetaS, or a minimal clinically relevant effect size called with a non-null esMinName name

alternative

a character string specifying the alternative hypothesis must be one of "twoSided" (default), "greater" or "less".

esMinName

provides the name of the effect size. Either "meanDiffMin" for the z-test, "deltaMin" for the t-test, or "hrMin" for the logrank test

paramDomain

Domain of the paramToCheck, typically, positiveNumbers. Default NULL