Learn R Programming

safestats (version 0.8.7)

checkAndReturnsNPlan: Check consistency between nPlan and the testType for one and two-sample z and t-tests

Description

Check consistency between nPlan and the testType for one and two-sample z and t-tests

Usage

checkAndReturnsNPlan(
  nPlan,
  ratio = 1,
  testType = c("oneSample", "paired", "twoSample")
)

Value

nPlan a vector of sample sizes of length 1 or 2

Arguments

nPlan

optional numeric vector of length at most 2. When provided, it is used to find the safe test defining parameter phiS. Note that if the purpose is to plan based on nPlan alone, then both meanDiffMin and beta should be set to NULL.

ratio

numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1.

testType

either one of "oneSample", "paired", "twoSample".