| checkDoubleArgumentsDesignObject | R Documentation |
Helper function to check whether arguments are specified in a function at a higher level and already provided in the design object.
checkDoubleArgumentsDesignObject(designObj, ...)
designObj |
an object of class "safeDesign". |
... |
arguments that need checking. |
Returns nothing only used for its side-effects to produces warnings if needed.
designObj <- designSaviZ(0.4)
checkDoubleArgumentsDesignObject(designObj, "alpha"=NULL, alternative=NULL)
# Throws a warning
checkDoubleArgumentsDesignObject(designObj, "alpha"=0.4, alternative="d")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.