| compute1F1AllVersions | R Documentation |
Repeated calls of genhypergeo,
which provides further details.
compute1F1AllVersions(U, L, z, tol = 0, maxiter = 2000)
U |
Upper arguments respectively (real or complex) |
L |
Lower arguments respectively (real or complex) |
z |
Primary complex argument |
tol |
tolerance with default zero meaning to iterate until additional terms to not change the partial sum |
maxiter |
Maximum number of iterations to perform |
a vector
compute1F1AllVersions(U=-359, L=1/2, z=-0.1891234)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.