computeConfidenceIntervalT: Helper function: Computes the savi confidence sequence for...

View source: R/tTest.R

computeConfidenceIntervalTR Documentation

Helper function: Computes the savi confidence sequence for the mean in a T-test

Description

Helper function: Computes the savi confidence sequence for the mean in a T-test

Usage

computeConfidenceIntervalT(
  meanObs,
  sdObs,
  nEff,
  nu,
  parameter,
  eType = c("mom", "eGauss", "imom", "eCauchy", "grow", "lai"),
  alternative = c("twoSided", "greater", "less"),
  ciValue = 0.95,
  maxRoot = 11,
  nuMin = 2
)

Arguments

meanObs

numeric, the observed mean. For two sample tests this is difference of the means.

sdObs

numeric, the observed standard deviation. For a two-sample test this is the root of the pooled variance.

nEff

numeric > 0, the effective sample size. For one sample tests, this is just n.

nu

numeric > 0, the degrees of freedom.

parameter

numeric > 0, the savi test defining parameter, see matchEParameterWith for details.

eType

character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior.

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less".

ciValue

numeric representing the confidence level. Default ciValue=NULL yields ciValue = 1 - alpha

maxRoot

Used to bound the candidate set of width of the confidence interval/

nuMin

numeric > 0, the minimum degrees of freedom under which the results are trivial, thus, 1.

Value

numeric vector that contains the upper and lower bound of the savi confidence sequence

Examples

computeConfidenceIntervalT(meanObs=0.3, sdObs=2, nEff=12, nu=11, parameter=0.4)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.