Learn R Programming

safestats (version 0.8.7)

computeNEff: Help function to compute the effective sample size based on a length 2 vector of samples

Description

Help function to compute the effective sample size based on a length 2 vector of samples

Usage

computeNEff(n, testType = c("oneSample", "paired", "twoSample"), silent = TRUE)

Value

a numeric that represents the effective sample size.

Arguments

n

vector of length at most 2 representing the sample sizes of the first and second group

testType

either one of "oneSample", "paired", "twoSample".

silent

logical, if true, then turn off warnings