computeNPlanBatchSaviZ: Helper function: Computes nPlan based on meanDiffTrue, alpha...

View source: R/zTest.R

computeNPlanBatchSafeZR Documentation

Helper function: Computes nPlan based on meanDiffTrue, alpha and power.

Description

Helper function: Computes nPlan based on meanDiffTrue, alpha and power.

Usage

computeNPlanBatchSaviZ(
  meanDiffTrue,
  alpha = 0.05,
  power = 0.8,
  sigma = 1,
  kappa = sigma,
  alternative = c("twoSided", "greater", "less"),
  testType = c("oneSample", "paired", "twoSample"),
  eType = c("mom", "eGauss", "imom", "eCauchy", "grow"),
  parameter = NULL,
  meanDiffMin = NULL,
  beta = NULL,
  highN = 10000L,
  ratio = 1,
  ...
)

Arguments

meanDiffTrue

numeric, data governing mean difference used for simulations. Default meanDiffTrue=meanDiffMin.

alpha

numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha.

beta

numerical in (0,1). Old parameter now replaced by the power parameter

sigma

numeric > 0 representing the assumed population standard deviation used to scale the data.

kappa

the true population standard deviation. Default kappa=sigma.

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less".

testType

either one of "oneSample", "paired", "twoSample".

eType

character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior.

parameter

numeric, an optional savi test defining parameter. Default set to NULL. and adapts to meanDiffMin and eType, see matchEParameterWith for details.

highN

integer, largest possible sampling horizon. This might be the largest n that we are able to fund, which by default is set to 1e4L. Typically, highN is not used, as the function computeNPlanBatchSaviZ() tries to find the sampling horizon. If all fails, then use highN as the sampling horizon.

ratio

numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1.

...

further arguments to be passed to or from methods.

power

numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore.

meanDiffMin

numeric that defines the minimal relevant mean difference, the smallest population mean difference that we would like to detect (with sufficient power).

Value

a list which contains at least nPlan and the savi test defining parameter.

Functions

  • computeNPlanBatchSafeZ(): Deprecated version of computeNPlanBatchSaviZ

References

Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.


safestats documentation built on Sept. 6, 2026, 1:06 a.m.