computeZTSumStats: Helper function to compute the relevant summary statistics in...

View source: R/tTest.R

computeZTSumStatsR Documentation

Helper function to compute the relevant summary statistics in z and t-tests

Description

Helper function to compute the relevant summary statistics in z and t-tests

Usage

computeZTSumStats(
  x,
  y = NULL,
  sequential = NULL,
  paired = FALSE,
  varEqual = TRUE,
  testType = NULL
)

Arguments

x

a (non-empty) numeric vector of data values.

y

an optional (non-empty) numeric vector of data values.

sequential

a logical indicating whether a sequential analysis should be performed.

paired

a logical, if TRUE then pair the data.

varEqual

a logical variable indicating whether to treat the two variances as being equal. Default varEqual=TRUE.

testType

either one of "oneSample", "paired", "twoSample".

Value

a list of summary statistics

Examples

n1 <- 23
n2 <- 39

x <- rnorm(n1, sd=7)
y <- rnorm(n2, sd=3)

computeZTSumStats(x=x, y=y)


safestats documentation built on Sept. 6, 2026, 1:06 a.m.