constructSampleStoppingTimesList: Construct a list to be set in the sampleStoppingTimes......

View source: R/designHelpers.R

constructSampleStoppingTimesListR Documentation

Construct a list to be set in the sampleStoppingTimes... function

Description

Construct a list to be set in the sampleStoppingTimes... function

Usage

constructSampleStoppingTimesList(
  nSim = 1000L,
  nMax = 1000L,
  wantEValuesAtNMax = FALSE,
  wantSamplePaths = TRUE
)

Arguments

nSim

integer > 0, the number of simulations needed to compute power or the number of samples paths for the savi z test under continuous monitoring.

nMax

integer > 0, maximum sample size of the (first) sample in each sample path.

wantEValuesAtNMax

logical. If TRUE, then compute eValues at nMax. Default FALSE.

wantSamplePaths

logical. If TRUE, then output the (stopped) sample paths. Default TRUE.

Value

a list with names

Examples

obj <- constructSampleStoppingTimesList()

safestats documentation built on Sept. 6, 2026, 1:06 a.m.