constructSaviDesignObj: Construct a savi design object to be set in the design...

View source: R/safeS3Methods.R

constructSafeDesignObjR Documentation

Construct a savi design object to be set in the design function

Description

Construct a savi design object to be set in the design function

Usage

constructSaviDesignObj(testName)

Arguments

testName

The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions".

Value

a savi design object

Functions

  • constructSafeDesignObj(): Deprecated version of constructSaviDesignObj

Examples

obj <- constructSaviDesignObj("Z-Test")

safestats documentation built on Sept. 6, 2026, 1:06 a.m.