constructSaviTestObj: Construct a savi test object to be set in the savi testing...

View source: R/safeS3Methods.R

constructSafeTestObjR Documentation

Construct a savi test object to be set in the savi testing function

Description

Construct a savi test object to be set in the savi testing function

Usage

constructSaviTestObj(testName)

Arguments

testName

The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions".

Value

a savi test object

Functions

  • constructSafeTestObj(): Deprecated version of constructSaviTestObj

Examples

obj <- constructSaviTestObj("Z-Test")

safestats documentation built on Sept. 6, 2026, 1:06 a.m.