fnchLogPartition: Log partition function of Fisher's noncentral hypergeometric...

View source: R/newsafe2x2Test.R

fnchLogPartitionR Documentation

Log partition function of Fisher's noncentral hypergeometric distribution

Description

Log partition function of Fisher's noncentral hypergeometric distribution

Usage

fnchLogPartition(na, nb, totalSuccesses, logOdds)

Arguments

na

number of observations in group A per data block, one value or one per block.

nb

number of observations in group B per data block, one value or one per block.

totalSuccesses

nonnegative integer, the total successes ya + yb in the table, at most na + nb.

logOdds

numeric, one log odds ratio logit(thetaA) - logit(thetaB).

Value

A numeric, the log of the sum over the feasible k of choose(na, k) * choose(nb, totalSuccesses - k) * exp(logOdds * k).


safestats documentation built on Oct. 5, 2026, 9:07 a.m.