Helper function that outputs the alternative hypothesis of the analysis.
getNameAlternative(
alternative = c("twoSided", "greater", "less"),
testType,
h0 = 0
)Returns a character string with the name of the analysis.
A character string. "twoSided", "greater", "less".
A character string either "oneSample", "paired", "twoSample", "gLogrank", or "eLogrank".
the value of the null hypothesis