getNameTestType: Gets the Label of the Test

View source: R/safeS3Methods.R

getNameTestTypeR Documentation

Gets the Label of the Test

Description

Helper function that outputs the name of the analysis.

Usage

getNameTestType(testType, testName, relevanceTest = FALSE)

Arguments

testType

A character string. For the t-tests: "oneSample", "paired", "twoSample".

testName

The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions".

relevanceTest

logical, if TRUE then impose a rule to stop for minimal efficiency if e <= alphaRelevance. Default FALSE.

Value

Returns a character string with the name of the analysis.


safestats documentation built on Sept. 6, 2026, 1:06 a.m.