Learn R Programming

safestats (version 0.8.7)

isTryError: Checks Whether a Vector of Object Inherits from the Class 'try-error'

Description

Checks whether any of the provided objects contains a try error.

Usage

isTryError(...)

Value

Returns TRUE if there's some object that's a try-error, FALSE when all objects are not try-errors.

Arguments

...

objects that need testing.

Examples

Run this code
x <- 1
y <- "a"
z <- try(integrate(exp, -Inf, Inf))
isTryError(x, y)
isTryError(x, y, z)

Run the code above in your browser using DataLab