logEValueVec2x2LogOddsEGauss: Plain eGauss e-process for logOdds

View source: R/newsafe2x2Test.R

logEValueVec2x2LogOddsEGaussR Documentation

Plain eGauss e-process for logOdds

Description

The conditional likelihood of Fisher's noncentral hypergeometric distribution on blocks ⁠1..i⁠, mixed under the Normal prior gaussParameter on logOddsGrid restricted to the side of a one-sided alternative, over the hypergeometric null. The mixture for block i includes block i, which is valid because each factor conditions on its block's total.

Usage

logEValueVec2x2LogOddsEGauss(
  ya,
  yb,
  na,
  nb,
  gaussParameter = NULL,
  alternative = c("twoSided", "greater", "less"),
  logOddsGrid = seq(-20, 20, length.out = 2000)
)

Arguments

ya

positive observations/ events per data block in group A: a numeric with integer values between (and including) 0 and na, the number of observations in group A per block.

yb

positive observations/ events per data block in group B: a numeric with integer values between (and including) 0 and nb, the number of observations in group B per block.

na

number of observations in group A per data block, one value or one per block.

nb

number of observations in group B per data block, one value or one per block.

gaussParameter

list(mean, sd), the Normal prior on logOdds for "eGauss", restricted to the grid ⁠(-20, 20)⁠ and to the side of a one-sided alternative; NULL means list(mean = 0, sd = 1).

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less", where "greater" means that group A has the larger proportion.

logOddsGrid

numeric vector, the grid the prior is normalised on.

Value

A numeric vector, element i the log e-value on blocks ⁠1..i⁠.


safestats documentation built on Oct. 5, 2026, 9:07 a.m.