logEValueVec2x2LogOddsGrow: Plain grow e-process for logOdds

View source: R/newsafe2x2Test.R

logEValueVec2x2LogOddsGrowR Documentation

Plain grow e-process for logOdds

Description

The cumulative conditional log likelihood ratio of logLikelihoodFNCH() at logOddsMin, signed by alternative, over the hypergeometric null. "twoSided" runs both signs of the magnitude and averages their cumulative e-processes.

Usage

logEValueVec2x2LogOddsGrow(
  ya,
  yb,
  na,
  nb,
  logOddsMin,
  alternative = c("twoSided", "greater", "less")
)

Arguments

ya

positive observations/ events per data block in group A: a numeric with integer values between (and including) 0 and na, the number of observations in group A per block.

yb

positive observations/ events per data block in group B: a numeric with integer values between (and including) 0 and nb, the number of observations in group B per block.

na

number of observations in group A per data block, one value or one per block.

nb

number of observations in group B per data block, one value or one per block.

logOddsMin

numeric that defines the minimal relevant log odds ratio logit(thetaA) - logit(thetaB).

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less", where "greater" means that group A has the larger proportion.

Value

A numeric vector, element i the log e-value on blocks ⁠1..i⁠.


safestats documentation built on Oct. 5, 2026, 9:07 a.m.