makeRunningIntersection: Helper function to create running intersections

View source: R/helpers.R

makeRunningIntersectionR Documentation

Helper function to create running intersections

Description

Helper function to create running intersections

Usage

makeRunningIntersection(x, upper = TRUE)

Arguments

x

vector of numeric, representing a sequence of upper or lower bounds of a confidence sequence

upper

logic, by default TRUE to construct a running intersection for the upper bound of a sequence with the minimum function. If FALSE, then use the maximum function for the lower bound.

Value

a sequence of numerics representing the running minimum or maximum

Examples


makeRunningIntersection(c(6, -1, 3, 12))

safestats documentation built on Sept. 6, 2026, 1:06 a.m.