matchEParameterWith: Match the parameter of a savi z or t-test

View source: R/designHelpers.R

matchEParameterWithR Documentation

Match the parameter of a savi z or t-test

Description

Based on the minimal clinically relevant effect size esMin, sigma (for z-tests), alternative and eType

Usage

matchEParameterWith(
  esMin,
  analysisType = c("z", "t", "logRank"),
  sigma = 1,
  alternative = c("twoSided", "greater", "less"),
  eType = c("mom", "eGauss", "imom", "eCauchy", "grow"),
  parameter = NULL
)

Arguments

esMin

numeric: meanDiffMin for z-tests, or deltaMin for t-tests

analysisType

character. Either "z", "t", or "logRank", currently.

sigma

numeric > 0 representing the assumed population standard deviation used to scale the data.

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less".

eType

character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior.

parameter

numeric, an optional savi test defining parameter. Default set to NULL. and adapts to meanDiffMin and eType, see matchEParameterWith for details.

Value

the parameter, a numeric value

Examples

matchEParameterWith(0.4)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.