matchPowerWith: Helper function to check whether the power or beta (redundant...

View source: R/designHelpers.R

matchPowerWithR Documentation

Helper function to check whether the power or beta (redundant now) argument is given

Description

Helper function to check whether the power or beta (redundant now) argument is given

Usage

matchPowerWith(power, beta = NULL)

Arguments

power

numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore.

beta

numerical in (0,1). Old parameter now replaced by the power parameter

Value

numeric representing power

Examples

matchPowerWith(0.8)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.