matchRelevanceParameterWith: Match the parameter of a minimal efficacy savi z-test

View source: R/designHelpers.R

matchRelevanceParameterWithR Documentation

Match the parameter of a minimal efficacy savi z-test

Description

Based on the relevanceSize, meanDiffMin, alternative and eType

Usage

matchRelevanceParameterWith(relevanceSize, esMin, esTrue)

Arguments

relevanceSize

numeric, the minimal clinical relevant mean difference that we do not want to miss under the alternative. Default relevanceSize=NULL implies relevanceSize=abs(meanDiffMin)

esMin

numeric: meanDiffMin for z-tests, or deltaMin for t-tests

esTrue

numeric. meanDiffTrue for z-tests, or deltaTrue for t-tests

Value

the parameter, a numeric value

Examples

matchRelevanceParameterWith(0.4)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.