plot.saviDesign: Plots the saviDesign object for designs with sample paths

View source: R/safeS3Methods.R

plot.safeDesignR Documentation

Plots the saviDesign object for designs with sample paths

Description

Plots the saviDesign object for designs with sample paths

Usage

## S3 method for class 'saviDesign'
plot(
  x,
  main = NULL,
  xlab = NULL,
  ylab = NULL,
  xlim = NULL,
  ylim = NULL,
  maxNBins = 40,
  numSamplePaths = 100,
  wantStepLines = FALSE,
  wantQuantiles = NULL,
  breaks = NULL,
  lwd = 2,
  pch = 15,
  colQuant = "#AA0000",
  overColour = "#8FC6E3",
  overColourBorder = "#1F78B4E6",
  underColour = "#E7A72199",
  underColourBorder = "#BD8E17FF",
  continueColour = "#8CA252E6",
  continueColourBorder = "#637939E6",
  histInnerColour = col,
  col = overColour,
  border = overColourBorder,
  cex = 1.3,
  yLabPAdj = -1,
  wantNotStoppedHist = FALSE,
  wantNotStoppedSamplePaths = TRUE,
  wantLegend = TRUE,
  legendAdjRelevance = c(-0.1, 0.5, 1),
  legendAdj = c(0.2, 0.8),
  legendCexFactor = 0.85,
  histFewestAtTop = FALSE,
  density = NULL,
  wantTitle = TRUE,
  ...
)

Arguments

x

designObj

main

character string for the title of plot

xlab

character string for the x-axis

ylab

character string for the y-axis

xlim

vector of length 2 specifying the range of the x-axis

ylim

vector of length 2 specifying the range of the y-axis

maxNBins

integer, maximum number of bins of the histogram

numSamplePaths

integer, number of sample paths to plot

wantStepLines

logical, if TRUE, then plot the sample paths as step functions (realistic).

wantQuantiles

a vector of numerics between zero and one representing the quantile levels

border

the color of the border around the bars. The default is to use blue

breaks

Break points of the histogram see hist()

lwd

The line width, a positive number, defaulting to 2.

pch

An integer specifying a symbol.

histInnerColour

A colour to be used to fill the bars.

col

colour of the lines

colQuant

colour of the quantiles

cex

size of the labels and the quantile text

...

further arguments to be passed to or from methods.

overColour

colour of an e-value sequence that cross the upper boundary of 1/alpha

overColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that cross the upper boundary of 1/alpha

underColour

colour of an e-value sequence that cross the lower boundary of alphaRelevance

underColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that cross the lower boundary of alphaRelevance

continueColour

colour for lines of e-values that did not (yet) cross a threshold

continueColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that did not (yet) cross a threshold

yLabPAdj

numeric to adjust the position of the y-axis label

wantNotStoppedHist

logical, if TRUE then show histogram of not stopped paths

wantNotStoppedSamplePaths

logical, if TRUE then show stopped sample paths of e-values

wantLegend

logical, if TRUE then show information of the percentage of stopped sample paths

legendAdjRelevance

vector of 3 numerics that allow for the adjustment of the percentages shown at the bottom of the plot, when relevance testing is on

legendAdj

vector of 2 numerics that allow for the adjustment of the percentages shown at the bottom of the plot

legendCexFactor

numeric, additional factor to control the text size of the additional information such as the percentages at the bottom of the plot

histFewestAtTop

logical, if TRUE, then fewest counts (of against the null or against minimal efficacy) at the top of the histogram

density

the density of shading lines, in lines per inch. The default value of NULL means that no shading lines are drawn. Non-positive values of density also inhibit the drawing of shading lines.

wantTitle

logical, if TRUE then add title

Value

Nothing it only plots

Functions

  • plot(safeDesign): Deprecated version of plot.saviDesign


safestats documentation built on Sept. 6, 2026, 1:06 a.m.