plot.saviTest: Plots the saviTest object for sequential analyses

View source: R/safeS3Methods.R

plot.safeTestR Documentation

Plots the saviTest object for sequential analyses

Description

Plots the saviTest object for sequential analyses

Usage

## S3 method for class 'saviTest'
plot(
  x,
  main = NULL,
  xlab = NULL,
  ylab = NULL,
  xlim = NULL,
  ylim = NULL,
  lwd = 3,
  cex = 1.3,
  fillPlot = NULL,
  switchNFill = 10000,
  logScale = NULL,
  switchNLog = 30,
  h0Colour = "darkgrey",
  overColour = "#8FC6E3",
  overColourBorder = "#1F78B4E6",
  underColour = "#E7A72199",
  underColourBorder = "#BD8E17FF",
  continueColour = "#8CA252E6",
  continueColourBorder = "#637939E6",
  col = overColour,
  border = overColourBorder,
  wantConfSeqPlot = FALSE,
  add = FALSE,
  density = NULL,
  angle = 45,
  xaxt = NULL,
  yaxt = NULL,
  fillOddEven = FALSE,
  runInt = TRUE,
  wantRelevance = NULL,
  ...
)

Arguments

x

designObj

main

character string for the title of plot

xlab

character string for the x-axis

ylab

character string for the y-axis

xlim

vector of length 2 specifying the range of the x-axis

ylim

vector of length 2 specifying the range of the y-axis

lwd

The line width, a positive number, defaulting to 2.

cex

size of the labels and the quantile text

fillPlot

logical, if TRUE then plot the confidence sequence with a background colour

switchNFill

integer, if is.null(fillPlot), then fill if the number of samples is smaller than switchNFill

logScale

logical, if TRUE then plot on the logscale

switchNLog

integer, if is.null(logScale), then plot on the log scale if the number of samples is larger than switchNLog

h0Colour

Colour to indicate the null hypothesis.

col

The colour for filling the anytime-valid confidence interval.

border

The colour to draw the border.

wantConfSeqPlot

logical, if TRUE then plot the confidence sequence instead of the e-value progression

add

logical, default FALSE so a new plot is made. If TRUE and wantConfSeqPlot==FALSE then adds the e-value progression line to an existing plot. If TRUE and wantConfSeqPlot==TRUE then adds another anytime-valid confidence sequence.

density

the density of shading lines, in lines per inch. The default value of NULL means that no shading lines are drawn. A zero value of density means no shading nor filling whereas negative values and NA suppress shading (and so allow colour filling).

angle

the slope of shading lines, given as an angle in degrees (anti-clockwise).

fillOddEven

logical controlling the polygon shading mode: see polygon() for details. Default FALSE.

...

further arguments to be passed to or from methods.

overColour

colour of an e-value sequence that cross the upper boundary of 1/alpha

overColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that cross the upper boundary of 1/alpha

underColour

colour of an e-value sequence that cross the lower boundary of alphaRelevance

underColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that cross the lower boundary of alphaRelevance

continueColour

colour for lines of e-values that did not (yet) cross a threshold

continueColourBorder

colour for the border of a rectangle in the histogram corresponding to e-values that did not (yet) cross a threshold

xaxt

default NULL. If "n" then suppresses plotting of the x-axis.

yaxt

default NULL. If "n" then suppresses plotting of the y-axis.

runInt

logical, if TRUE (default), then shows the running intersection of the confidence sequence.

wantRelevance

logical, if FALSE, then don't show the e-values for relevanceTest. Default wantRelevance==NULL, if designObj[["relevanceTest"]]==TRUE then relevance e-values tests are shown automatically.

Value

Returns nothing just plots

Functions

  • plot(safeTest): Deprecated version of plot.saviTest


safestats documentation built on Sept. 6, 2026, 1:06 a.m.