plotHistogramDistributionStoppingTimes: Plots the Histogram of Stopping Times

View source: R/vignetteHelpers.R

plotHistogramDistributionStoppingTimesR Documentation

Plots the Histogram of Stopping Times

Description

Helper function to display the histogram of stopping times.

Usage

plotHistogramDistributionStoppingTimes(
  saviSim,
  nPlan,
  deltaTrue,
  showOnlyNRejected = FALSE,
  nBin = 25L,
  ...
)

Arguments

saviSim

A saviSim object

nPlan

numeric > 0, the planned sample size(s).

deltaTrue

numeric, that represents the true underlying standardised effect size delta.

showOnlyNRejected

logical, when TRUE discards the cases that did not reject.

nBin

numeric > 0, the minimum number of bins in the histogram.

...

further arguments to be passed to or from methods.

Value

a histogram object, and called for its side-effect to plot the histogram.


safestats documentation built on Sept. 6, 2026, 1:06 a.m.