powered by
Printing objects of class 'safeTest' modelled after print.htest().
print.htest()
# S3 method for safeTest print(x, digits = getOption("digits"), prefix = "\t", ...)
No returned value, called for side effects.
a safeTest object.
number of significant digits to be used.
string, passed to strwrap for displaying the method components.
further arguments to be passed to or from methods.
safeTTest(rnorm(19), pilot=TRUE) safeZTest(rnorm(19), pilot=TRUE)
Run the code above in your browser using DataLab