View source: R/safeS3Methods.R
| print.safeDesign | R Documentation |
Printing objects of class 'saviTest' modelled after print.power.htest().
## S3 method for class 'saviDesign'
print(x, digits = getOption("digits"), prefix = "\t", ...)
x |
a saviTest object. |
digits |
number of significant digits to be used. |
prefix |
string, passed to strwrap for displaying the method components. |
... |
further arguments to be passed to or from methods. |
No returned value, called for side effects.
print(safeDesign): Deprecated version of print.saviDesign
designSaviZ(meanDiffMin=0.5)
designSaviT(deltaMin=0.5)
designSaviLogrank(hrMin=0.7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.