View source: R/safeS3Methods.R
| print.safeTest | R Documentation |
Printing objects of class 'saviTest' modelled after print.htest().
## S3 method for class 'saviTest'
print(x, digits = getOption("digits"), prefix = "\t", ...)
x |
a saviTest object. |
digits |
number of significant digits to be used. |
prefix |
string, passed to strwrap for displaying the method components. |
... |
further arguments to be passed to or from methods. |
No returned value, called for side effects.
print(safeTest): Deprecated version of print.saviTest
saviTTest(rnorm(19))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.