returnOne: Auxiliary function for sampling of the logrank simulations to...

View source: R/logRankTest.R

returnOneR Documentation

Auxiliary function for sampling of the logrank simulations to return the integer 1 event per time.

Description

Auxiliary function for sampling of the logrank simulations to return the integer 1 event per time.

Usage

returnOne()

Value

1

Examples

returnOne()

safestats documentation built on Sept. 6, 2026, 1:06 a.m.