Learn R Programming

safestats (version 0.8.7)

safeZ10Inverse: Computes the Inverse of the Two-Sided Safe Z-Test

Description

This helper function is used in designSafeZ() to find parameter. The function is the (two-sided) inverse of 'safeZTestStat'.

Usage

safeZ10Inverse(parameter, nEff, sigma = 1, alpha = 0.05)

Value

A number that represents a z-value. The function's domain is the positive real line and the range is the real line, i.e., the outcome space of the z-statistic.

Arguments

parameter

optional test defining parameter. Default set to NULL.

nEff

numeric > 0, the effective sample size.

sigma

numeric, the assumed known standard deviation, default 1.

alpha

numeric in (0, 1) that specifies the tolerable type I error control --independent on n-- that the designed test has to adhere to. Note that it also defines the rejection rule e10 > 1/alpha.

Examples

Run this code
safeZ10Inverse(0.4, n=13)

Run the code above in your browser using DataLab