savi2x2TestStatUmp: UMP conditional e-value of one 2x2 table

View source: R/newsafe2x2Test.R

savi2x2TestStatUmpR Documentation

UMP conditional e-value of one 2x2 table

Description

The e-value of the conditional test on one table: the likelihood of logLikelihoodFNCH() at the uniformly most powerful log odds ratio of solveUmpLogOdds() over the hypergeometric null. "twoSided" averages the two one-sided e-values. The test uses it in place of block 1's plain factor.

Usage

savi2x2TestStatUmp(
  ya,
  yb,
  na,
  nb,
  alpha,
  alternative = c("twoSided", "greater", "less")
)

Arguments

ya

positive observations/ events per data block in group A: a numeric with integer values between (and including) 0 and na, the number of observations in group A per block.

yb

positive observations/ events per data block in group B: a numeric with integer values between (and including) 0 and nb, the number of observations in group B per block.

na

number of observations in group A per data block, one value or one per block.

nb

number of observations in group B per data block, one value or one per block.

alpha

numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha.

alternative

a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less", where "greater" means that group A has the larger proportion.

Value

A numeric, or NULL when no one-sided UMP log odds ratio exists at level alpha.


safestats documentation built on Oct. 5, 2026, 9:07 a.m.