tTestWidthDerivative: Internal function to solve the smallest width of an eGauss...

View source: R/tTest.R

tTestWidthDerivativeR Documentation

Internal function to solve the smallest width of an eGauss t-test

Description

Internal function to solve the smallest width of an eGauss t-test

Usage

tTestWidthDerivative(g, nEff, nu, alpha = 0.05)

Arguments

g

prior variance of the eGauss t-test

nEff

numeric > 0, the effective sample size. For one sample tests, this is just n.

nu

numeric > 0, the degrees of freedom.

alpha

numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha.

Value

a number that should be zero when g is optimal

References

Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.

Examples

tTestWidthDerivative(1, 1, 1)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.