zMarg: Logarithmic marginal likelihood of the normal with conjugate...

View source: R/zTest.R

zMargR Documentation

Logarithmic marginal likelihood of the normal with conjugate priors

Description

Logarithmic marginal likelihood of the normal with conjugate priors

Usage

zMarg(n, x, s2, a = 0, b = 1, sigma = 1)

Arguments

n

integer, sample size

x

numeric, sample mean

s2

numeric > 0, sample variance

a

numeric, prior mean of the population mean mu

b

numeric > 0, prior standard deviation of the population mean mu

sigma

numeric > 0, population standard deviation

Value

numeric, the logarithm of the marginal likelihood

Examples

zMarg(12, 0.3, 2)

safestats documentation built on Sept. 6, 2026, 1:06 a.m.