| computeBetaBatchSafeZ | R Documentation |
Helper function: Computes 1-power based on meanDiffTrue and nPlan
computeBetaBatchSaviZ(
meanDiffTrue,
nPlan,
alpha = 0.05,
sigma = 1,
kappa = sigma,
alternative = c("twoSided", "greater", "less"),
testType = c("oneSample", "paired", "twoSample"),
parameter = NULL,
eType = c("mom", "eGauss", "imom", "eCauchy", "grow")
)
meanDiffTrue |
numeric, data governing mean difference used for simulations. Default meanDiffTrue=meanDiffMin. |
nPlan |
optional numeric vector of length at most 2, see scenario 2 and 3 above. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
sigma |
numeric > 0 representing the assumed population standard deviation used to scale the data. |
kappa |
the true population standard deviation. Default kappa=sigma. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
testType |
either one of "oneSample", "paired", "twoSample". |
parameter |
numeric, an optional savi test defining parameter. Default set to |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
numeric that represents the type II error
computeBetaBatchSafeZ(): Deprecated version of computeBetaBatchSaviZ
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.