View source: R/designHelpers.R
| computeBootObj | R Documentation |
Computes the bootObj for sequential sampling procedures regarding nPlan, beta, the implied target
computeBootObj(
values,
power = NULL,
nPlan = NULL,
nBoot = 1000L,
alpha = NULL,
beta = NULL,
objType = c("nPlan", "nMean", "power", "beta", "betaFromEValues", "logImpliedTarget",
"expectedStopTime")
)
values |
numeric vector. If objType equals "nPlan" or "beta" then values should be stopping times, if objType equals "logImpliedTarget" then values should be eValues. |
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
nPlan |
numeric vector of length at most 2 representing the planned sample size(s). |
nBoot |
integer > 0 representing the number of bootstrap samples to estimate the uncertainty of various estimates. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
objType |
character string either "nPlan", "nMean", "beta", "betaFromEValues", "expectedStopTime" or "logImpliedTarget". |
bootObj
computeBootObj(1:100, objType="nPlan", beta=0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.