Learn R Programming

safestats (version 0.8.7)

computeConfidenceIntervalT: Helper function: Computes the safe confidence sequence for the mean in a t-test

Description

Helper function: Computes the safe confidence sequence for the mean in a t-test

Usage

computeConfidenceIntervalT(
  meanObs,
  sdObs,
  nEff,
  nu,
  deltaS,
  ciValue = 0.95,
  g = NULL
)

Value

numeric vector that contains the upper and lower bound of the safe confidence sequence

Arguments

meanObs

numeric, the observed mean. For two sample tests this is difference of the means.

sdObs

numeric, the observed standard deviation. For a two-sample test this is the root of the pooled variance.

nEff

numeric > 0, the effective sample size. For one sample test this is just n.

nu

numeric > 0, the degrees of freedom.

deltaS

numeric > 0, the safe test defining parameter.

ciValue

numeric is the ciValue-level of the confidence sequence. Default ciValue=0.95.

g

numeric > 0, used as the variance of the normal prior on the population delta Default is NULL in which case g=delta^2.

Examples

Run this code
computeConfidenceIntervalT(meanObs=0.3, sdObs=2, nEff=12, nu=11, deltaS=0.4)

Run the code above in your browser using DataLab