powered by
Helper function: Computes the safe confidence sequence for the mean in a t-test
computeConfidenceIntervalT( meanObs, sdObs, nEff, nu, deltaS, ciValue = 0.95, g = NULL )
numeric vector that contains the upper and lower bound of the safe confidence sequence
numeric, the observed mean. For two sample tests this is difference of the means.
numeric, the observed standard deviation. For a two-sample test this is the root of the pooled variance.
numeric > 0, the effective sample size. For one sample test this is just n.
numeric > 0, the degrees of freedom.
numeric > 0, the safe test defining parameter.
numeric is the ciValue-level of the confidence sequence. Default ciValue=0.95.
numeric > 0, used as the variance of the normal prior on the population delta Default is NULL in which case g=delta^2.
NULL
computeConfidenceIntervalT(meanObs=0.3, sdObs=2, nEff=12, nu=11, deltaS=0.4)
Run the code above in your browser using DataLab