Help function to compute the effective sample size based on a length 2 vector of samples
computeNEff(n, testType = c("oneSample", "paired", "twoSample"), silent = TRUE)a numeric that represents the effective sample size.
vector of length at most 2 representing the sample sizes of the first and second group
either one of "oneSample", "paired", "twoSample".
logical, if true, then turn off warnings