| computeNPlanBatchSaviT | R Documentation |
Helper function: Computes the planned sample size for the savi T-test based deltaMin, alpha and power
computeNPlanBatchSaviT(
deltaTrue,
alpha = 0.05,
power = 0.8,
alternative = c("twoSided", "greater", "less"),
testType = c("oneSample", "paired", "twoSample"),
eType = c("mom", "eGauss", "imom", "eCauchy", "grow", "lai"),
sigma = 1,
sigma2 = 1,
parameter = NULL,
beta = NULL,
ratio = 1,
deltaMin = NULL,
...
)
deltaTrue |
numeric, data governing effect size used for simulations. Default deltaTrue=deltaMin. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
testType |
either one of "oneSample", "paired", "twoSample". |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
sigma |
numeric > 0 representing the population standard deviation used for the test. |
sigma2 |
numeric > 0 representing the population standard deviation used for the test, for the second group in a two-sample t-test |
parameter |
numeric, an optional savi test defining parameter. Default set to |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
ratio |
numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1. |
deltaMin |
numeric that defines the minimal relevant standardised mean difference, the smallest population effect size that we would like to detect (with sufficient power). |
... |
further arguments to be passed to or from methods, but mainly to perform do.calls. |
a list which contains at least nPlan and the savi test defining parameter
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.