View source: R/designHelpers.R
| computeNPlanBootstrapper | R Documentation |
Helper function to compute uncertainty regarding nPlan estimates
computeNPlanBootstrapper(
samplingResult,
parameter,
power,
nPlanBatch,
nBoot,
beta = NULL
)
samplingResult |
output from sampling functions such as computeNPlanSaviZ and computeNPlanSaviT |
parameter |
numeric > 0, the savi test defining parameter. |
power |
numeric in (0, 1) that specifies the desirable power necessary to calculate both "n" and the minimum detectable effect size. |
nPlanBatch |
integer, the sample size needed in a batch design to reach the targeted power=1-beta with tolerable type I error alpha |
nBoot |
integer > 0 representing the number of bootstrap samples to estimate the uncertainty of various estimates. |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
list with bootstrap objects
samplingResult <- sampleStoppingTimesSaviT(0.7, nSim=10, nMax=20)
result <- computeNPlanBootstrapper(samplingResult, 0.7, 0.2, 20, nBoot=1e2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.