| computeZTSumStats | R Documentation |
Helper function to compute the relevant summary statistics in z and t-tests
computeZTSumStats(
x,
y = NULL,
sequential = NULL,
paired = FALSE,
varEqual = TRUE,
testType = NULL
)
x |
a (non-empty) numeric vector of data values. |
y |
an optional (non-empty) numeric vector of data values. |
sequential |
a logical indicating whether a sequential analysis should be performed. |
paired |
a logical, if |
varEqual |
a logical variable indicating whether to treat the two variances as being equal. Default varEqual=TRUE. |
testType |
either one of "oneSample", "paired", "twoSample". |
a list of summary statistics
n1 <- 23
n2 <- 39
x <- rnorm(n1, sd=7)
y <- rnorm(n2, sd=3)
computeZTSumStats(x=x, y=y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.