View source: R/designHelpers.R
| constructSampleStoppingTimesList | R Documentation |
Construct a list to be set in the sampleStoppingTimes... function
constructSampleStoppingTimesList(
nSim = 1000L,
nMax = 1000L,
wantEValuesAtNMax = FALSE,
wantSamplePaths = TRUE
)
nSim |
integer > 0, the number of simulations needed to compute power or the number of samples paths for the savi z test under continuous monitoring. |
nMax |
integer > 0, maximum sample size of the (first) sample in each sample path. |
wantEValuesAtNMax |
logical. If |
wantSamplePaths |
logical. If |
a list with names
obj <- constructSampleStoppingTimesList()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.