View source: R/safeS3Methods.R
| constructSafeDesignObj | R Documentation |
Construct a savi design object to be set in the design function
constructSaviDesignObj(testName)
testName |
The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions". |
a savi design object
constructSafeDesignObj(): Deprecated version of constructSaviDesignObj
obj <- constructSaviDesignObj("Z-Test")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.