View source: R/safeS3Methods.R
| constructSafeTestObj | R Documentation |
Construct a savi test object to be set in the savi testing function
constructSaviTestObj(testName)
testName |
The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions". |
a savi test object
constructSafeTestObj(): Deprecated version of constructSaviTestObj
obj <- constructSaviTestObj("Z-Test")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.