| defineTTestN | R Documentation |
Helper function that outputs a sequence of sample sizes, effective sample sizes, and the degrees of freedom depending on the type of T-test. Also used for Z-tests.
defineTTestN(
lowN = 3,
highN = 100,
ratio = 1,
testType = c("oneSample", "paired", "twoSample")
)
lowN |
integer that defines the smallest n of our search space for n. |
highN |
integer largest sample size of the (first) sample. Default set to 100. |
ratio |
numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1. |
testType |
either one of "oneSample", "paired", "twoSample". |
Returns the sample sizes and degrees of freedom.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.