| designFreqT | R Documentation |
Computes the number of samples necessary to reach a tolerable type I and desired power for the frequentist T-test.
designFreqT(
deltaMin,
alpha = 0.05,
power = 0.8,
alternative = c("twoSided", "greater", "less"),
h0 = 0,
testType = c("oneSample", "paired", "twoSample"),
...
)
deltaMin |
numeric that defines the minimal relevant standardised mean difference, the smallest population effect size that we would like to detect (with sufficient power). |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
h0 |
numeric, representing the null value, default h0=0. |
testType |
either one of "oneSample", "paired", "twoSample". |
... |
further arguments to be passed to or from methods, but mainly to perform do.calls. |
Returns an object of class 'freqTDesign'. An object of class 'freqTDesign' is a list containing at least the following components:
the planned sample size(s).
the minimal clinically relevant standardised effect size provided by the user.
the tolerable type I error provided by the user.
the desired power provided by the user.
the smallest n of the search space for n provided by the user.
the largest n of the search space for n provided by the user.
any of "oneSample", "paired", "twoSample" provided by the user.
any of "twoSided", "greater", "less" provided by the user.
designFreqT(0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.