| designSaviT2WantPower | R Documentation |
Finds the parameter and power when provided with only alpha, esMin, and nPlan
designSaviT2WantPower(
deltaTrue,
nPlan,
alpha = 0.05,
alternative = c("twoSided", "greater", "less"),
deltaMin = deltaTrue,
testType = c("oneSample", "paired", "twoSample"),
ratio = 1,
parameter = NULL,
eType = c("mom", "eGauss", "imom", "eCauchy", "grow", "lai"),
wantSamplePaths = TRUE,
wantSimData = TRUE,
relevanceTest = FALSE,
relevanceSize = NULL,
alphaRelevance = NULL,
pb = TRUE,
seed = NULL,
nSim = 1000L,
nBoot = nSim,
nuMin = 2,
...
)
deltaTrue |
numeric, data governing effect size used for simulations. Default deltaTrue=deltaMin. |
nPlan |
optional numeric vector of length at most 2, see scenario 2 and 3 above. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
deltaMin |
numeric that defines the minimal relevant standardised mean difference, the smallest population effect size that we would like to detect (with sufficient power). |
testType |
either one of "oneSample", "paired", "twoSample". |
ratio |
numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1. |
parameter |
numeric, an optional savi test defining parameter. Default set to |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
wantSamplePaths |
logical, if |
wantSimData |
logical, if |
relevanceTest |
logical, if |
relevanceSize |
numeric, the minimal clinical relevant mean difference that we do not want to miss under the alternative. Default relevanceSize=NULL implies relevanceSize=abs(meanDiffMin) |
alphaRelevance |
numeric, the threshold for relevance test. Taken to be minimum of alpha and 1-power. |
pb |
logical, if |
seed |
integer, seed number. |
nSim |
integer > 0, the number of simulations needed to compute power or the number of samples paths for the savi t test under continuous monitoring. |
nBoot |
integer > 0 representing the number of bootstrap samples to assess the accuracy of the approximations of the power, the number of samples for the savi t test under continuous monitoring,or for the computation of the logarithm of the implied target. |
nuMin |
numeric > 0, the minimum degrees of freedom under which the results are trivial, thus, 1. |
... |
further arguments to be passed to or from methods, but mainly to perform do.calls. |
A list with the parameter and beta amongst other items
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
designSaviT2WantPower(deltaTrue=0.9, nPlan=7, nSim=10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.