| designSaviT3WantEsMin | R Documentation |
Finds the parameter and esMin when provided with only alpha, power, and nPlan
designSaviT3WantEsMin(
power,
nPlan,
alpha = 0.05,
alternative = c("twoSided", "greater", "less"),
testType = c("oneSample", "paired", "twoSample"),
parameter = NULL,
beta = NULL,
eType = c("mom", "eGauss", "imom", "eCauchy", "grow", "lai"),
lowEsTrue = 0.01,
highEsTrue = 3,
...
)
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
nPlan |
optional numeric vector of length at most 2, see scenario 2 and 3 above. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
testType |
either one of "oneSample", "paired", "twoSample". |
parameter |
numeric, an optional savi test defining parameter. Default set to |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
lowEsTrue |
numeric, lower bound for the candidate set of the targeted minimal clinically relevant effect size for scenario 3.a. |
highEsTrue |
numeric, upper bound for the candidate set of the targeted minimal clinically relevant effect size for scenario 3.a. |
... |
further arguments to be passed to or from methods, but mainly to perform do.calls. |
A list with the parameter and the targeted esMin amongst other items
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
designSaviT3WantEsMin(power=0.7, nPlan=10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.