| designSafeZ3bWantParameter | R Documentation |
Finds the parameter and meanDiffMin when provided with only alpha, nPlan
designSaviZ3bWantParameter(
nPlan,
alpha = 0.05,
alternative = c("twoSided", "greater", "less"),
sigma = 1,
kappa = sigma,
testType = c("oneSample", "paired", "twoSample"),
parameter = NULL,
eType = c("mom", "eGauss", "imom", "eCauchy", "grow"),
...
)
nPlan |
optional numeric vector of length at most 2, see scenario 2 and 3 above. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
sigma |
numeric > 0 representing the assumed population standard deviation used to scale the data. |
kappa |
the true population standard deviation. Default kappa=sigma. |
testType |
either one of "oneSample", "paired", "twoSample". |
parameter |
numeric, an optional savi test defining parameter. Default set to |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
... |
further arguments to be passed to or from methods. |
A list with the parameter and the parameter amongst other items
designSafeZ3bWantParameter(): Deprecated version of designSaviZ3bWantParameter
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
designSaviZ3bWantParameter(nPlan=13)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.