View source: R/newsafe2x2Test.R
| fnchLogPartition | R Documentation |
Log partition function of Fisher's noncentral hypergeometric distribution
fnchLogPartition(na, nb, totalSuccesses, logOdds)
na |
number of observations in group A per data block, one value or one per block. |
nb |
number of observations in group B per data block, one value or one per block. |
totalSuccesses |
nonnegative integer, the total successes |
logOdds |
numeric, one log odds ratio |
A numeric, the log of the sum over the feasible k of
choose(na, k) * choose(nb, totalSuccesses - k) * exp(logOdds * k).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.