| generateNormalData | R Documentation |
The designs supported are "oneSample", "paired", "twoSample".
generateNormalData(
nPlan,
nSim = 1000L,
deltaTrue = NULL,
muGlobal = 0,
sigma = 1,
sigma2 = 1,
paired = FALSE,
seed = NULL,
meanDiffTrue = NULL
)
nPlan |
optional numeric vector of length at most 2, see scenario 2 and 3 above. |
nSim |
integer > 0, the number of simulations needed to compute power or the number of samples paths for the savi t test under continuous monitoring. |
deltaTrue |
numeric, the value of the true standardised effect size (test-relevant parameter).
This argument is used by |
muGlobal |
numeric, population grand mean |
sigma |
numeric > 0, population standard deviation |
sigma2 |
numeric > 0 representing the population standard deviation used for the test, for the second group in a two-sample t-test |
paired |
a logical, if |
seed |
integer, seed number. |
meanDiffTrue |
numeric, data governing parameter value |
Returns a list of two data matrices contains at least the following components:
a matrix of data dimension nSim by nPlan[1].
a matrix of data dimension nSim by nPlan[2].
generateNormalData(20, 15, deltaTrue=0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.