View source: R/safeS3Methods.R
| getNameTestType | R Documentation |
Helper function that outputs the name of the analysis.
getNameTestType(testType, testName, relevanceTest = FALSE)
testType |
A character string. For the t-tests: "oneSample", "paired", "twoSample". |
testName |
The name of the analysis that is performed such as "Z-Test", and "Test of Two Proportions". |
relevanceTest |
logical, if |
Returns a character string with the name of the analysis.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.