View source: R/newsafe2x2Test.R
| logEValueVec2x2LogOddsGrow | R Documentation |
The cumulative conditional log likelihood ratio of logLikelihoodFNCH()
at logOddsMin, signed by alternative, over the hypergeometric null.
"twoSided" runs both signs of the magnitude and averages their
cumulative e-processes.
logEValueVec2x2LogOddsGrow(
ya,
yb,
na,
nb,
logOddsMin,
alternative = c("twoSided", "greater", "less")
)
ya |
positive observations/ events per data block in group A: a
numeric with integer values between (and including) 0 and |
yb |
positive observations/ events per data block in group B: a
numeric with integer values between (and including) 0 and |
na |
number of observations in group A per data block, one value or one per block. |
nb |
number of observations in group B per data block, one value or one per block. |
logOddsMin |
numeric that defines the minimal relevant log odds
ratio |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less", where "greater" means that group A has the larger proportion. |
A numeric vector, element i the log e-value on blocks 1..i.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.