View source: R/newsafe2x2Test.R
| logEValueVec2x2PropDiffEBeta | R Documentation |
The cumulative log likelihood ratio of the predictive Beta means of
predictiveThetas2x2() over the pooled null mean
(na * thetaA + nb * thetaB) / (na + nb), block 1 included.
logEValueVec2x2PropDiffEBeta(ya, yb, na, nb, betaParameter)
ya |
positive observations/ events per data block in group A: a
numeric with integer values between (and including) 0 and |
yb |
positive observations/ events per data block in group B: a
numeric with integer values between (and including) 0 and |
na |
number of observations in group A per data block, one value or one per block. |
nb |
number of observations in group B per data block, one value or one per block. |
betaParameter |
|
A numeric vector, element i the log e-value on blocks 1..i.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.