| makeRunningIntersection | R Documentation |
Helper function to create running intersections
makeRunningIntersection(x, upper = TRUE)
x |
vector of numeric, representing a sequence of upper or lower bounds of a confidence sequence |
upper |
logic, by default |
a sequence of numerics representing the running minimum or maximum
makeRunningIntersection(c(6, -1, 3, 12))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.