View source: R/designHelpers.R
| matchAlphaRelevanceWith | R Documentation |
Checks and outputs a threshold for a minimal efficacy analysis
matchAlphaRelevanceWith(
alphaRelevance,
alpha = NULL,
power = NULL,
beta = NULL,
betaDefault = 0.2
)
alphaRelevance |
numeric > 0 and < 1, used to set the threshold of a minimal efficacy procedure |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
beta |
numeric > 0 and < 1, a tolerable type II error, used to set the threshold if alphaRelevance is not given |
betaDefault |
numeric > 0 and < 1 a default value (0.2) to run a minimal efficacy procedure |
a alphaRelevance threshold
matchAlphaRelevanceWith(0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.