View source: R/designHelpers.R
| matchPowerWith | R Documentation |
Helper function to check whether the power or beta (redundant now) argument is given
matchPowerWith(power, beta = NULL)
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
numeric representing power
matchPowerWith(0.8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.