View source: R/designHelpers.R
| matchRelevanceParameterWith | R Documentation |
Based on the relevanceSize, meanDiffMin, alternative and eType
matchRelevanceParameterWith(relevanceSize, esMin, esTrue)
relevanceSize |
numeric, the minimal clinical relevant mean difference that we do not want to miss under the alternative. Default relevanceSize=NULL implies relevanceSize=abs(meanDiffMin) |
esMin |
numeric: meanDiffMin for z-tests, or deltaMin for t-tests |
esTrue |
numeric. meanDiffTrue for z-tests, or deltaTrue for t-tests |
the parameter, a numeric value
matchRelevanceParameterWith(0.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.