View source: R/safeS3Methods.R
| plot.safeTest | R Documentation |
Plots the saviTest object for sequential analyses
## S3 method for class 'saviTest'
plot(
x,
main = NULL,
xlab = NULL,
ylab = NULL,
xlim = NULL,
ylim = NULL,
lwd = 3,
cex = 1.3,
fillPlot = NULL,
switchNFill = 10000,
logScale = NULL,
switchNLog = 30,
h0Colour = "darkgrey",
overColour = "#8FC6E3",
overColourBorder = "#1F78B4E6",
underColour = "#E7A72199",
underColourBorder = "#BD8E17FF",
continueColour = "#8CA252E6",
continueColourBorder = "#637939E6",
col = overColour,
border = overColourBorder,
wantConfSeqPlot = FALSE,
add = FALSE,
density = NULL,
angle = 45,
xaxt = NULL,
yaxt = NULL,
fillOddEven = FALSE,
runInt = TRUE,
wantRelevance = NULL,
...
)
x |
designObj |
main |
character string for the title of plot |
xlab |
character string for the x-axis |
ylab |
character string for the y-axis |
xlim |
vector of length 2 specifying the range of the x-axis |
ylim |
vector of length 2 specifying the range of the y-axis |
lwd |
The line width, a positive number, defaulting to 2. |
cex |
size of the labels and the quantile text |
fillPlot |
logical, if TRUE then plot the confidence sequence with a background colour |
switchNFill |
integer, if |
logScale |
logical, if TRUE then plot on the logscale |
switchNLog |
integer, if |
h0Colour |
Colour to indicate the null hypothesis. |
col |
The colour for filling the anytime-valid confidence interval. |
border |
The colour to draw the border. |
wantConfSeqPlot |
logical, if |
add |
logical, default |
density |
the density of shading lines, in lines per inch.
The default value of |
angle |
the slope of shading lines, given as an angle in degrees (anti-clockwise). |
fillOddEven |
logical controlling the polygon shading mode: see
|
... |
further arguments to be passed to or from methods. |
overColour |
colour of an e-value sequence that cross the upper boundary of 1/alpha |
overColourBorder |
colour for the border of a rectangle in the histogram corresponding to e-values that cross the upper boundary of 1/alpha |
underColour |
colour of an e-value sequence that cross the lower boundary of alphaRelevance |
underColourBorder |
colour for the border of a rectangle in the histogram corresponding to e-values that cross the lower boundary of alphaRelevance |
continueColour |
colour for lines of e-values that did not (yet) cross a threshold |
continueColourBorder |
colour for the border of a rectangle in the histogram corresponding to e-values that did not (yet) cross a threshold |
xaxt |
default NULL. If "n" then suppresses plotting of the x-axis. |
yaxt |
default NULL. If "n" then suppresses plotting of the y-axis. |
runInt |
logical, if |
wantRelevance |
logical, if |
Returns nothing just plots
plot(safeTest): Deprecated version of plot.saviTest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.