View source: R/vignetteHelpers.R
| plotHistogramDistributionStoppingTimes | R Documentation |
Helper function to display the histogram of stopping times.
plotHistogramDistributionStoppingTimes(
saviSim,
nPlan,
deltaTrue,
showOnlyNRejected = FALSE,
nBin = 25L,
...
)
saviSim |
A saviSim object |
nPlan |
numeric > 0, the planned sample size(s). |
deltaTrue |
numeric, that represents the true underlying standardised effect size delta. |
showOnlyNRejected |
logical, when |
nBin |
numeric > 0, the minimum number of bins in the histogram. |
... |
further arguments to be passed to or from methods. |
a histogram object, and called for its side-effect to plot the histogram.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.