View source: R/newsafe2x2Test.R
| predictiveThetas2x2 | R Documentation |
Independent Beta posteriors on thetaA and thetaB with prior shapes
betaParameter, updated with the blocks before each block: block i
uses blocks 1..i-1 only, and block 1 the prior.
predictiveThetas2x2(ya, yb, na, nb, betaParameter)
ya |
positive observations/ events per data block in group A: a
numeric with integer values between (and including) 0 and |
yb |
positive observations/ events per data block in group B: a
numeric with integer values between (and including) 0 and |
na |
number of observations in group A per data block, one value or one per block. |
nb |
number of observations in group B per data block, one value or one per block. |
betaParameter |
|
A list of numeric vectors thetaA and thetaB, one value per block.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.