A number that represents a z-value. The function's domain is the positive real line and the range
is the real line, i.e., the outcome space of the z-statistic.
Arguments
parameter
optional test defining parameter. Default set to NULL.
nEff
numeric > 0, the effective sample size.
sigma
numeric, the assumed known standard deviation, default 1.
alpha
numeric in (0, 1) that specifies the tolerable type I error control --independent on n-- that the
designed test has to adhere to. Note that it also defines the rejection rule e10 > 1/alpha.