| sampleStoppingTimesSafeZ | R Documentation |
Simulate stopping times for the savi Z-test
sampleStoppingTimesSaviZ(
meanDiffTrue,
alpha = 0.05,
alternative = c("twoSided", "less", "greater"),
testType = c("oneSample", "paired", "twoSample"),
sigma = 1,
kappa = sigma,
ratio = 1,
meanDiffMin = NULL,
parameter = NULL,
nMax = 1000L,
eType = c("mom", "eGauss", "imom", "eCauchy", "grow"),
wantEValuesAtNMax = FALSE,
power = NULL,
wantSamplePaths = TRUE,
wantSimData = TRUE,
pb = TRUE,
seed = NULL,
nSim = 1000L,
relevanceTest = FALSE,
relevanceSize = NULL,
beta = NULL,
alphaRelevance = NULL,
...
)
meanDiffTrue |
numeric, data governing mean difference used for simulations. Default meanDiffTrue=meanDiffMin. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
testType |
either one of "oneSample", "paired", "twoSample". |
sigma |
numeric > 0 representing the assumed population standard deviation used to scale the data. |
kappa |
the true population standard deviation. Default kappa=sigma. |
ratio |
numeric > 0 representing the randomisation ratio of condition 2 over condition 1. If testType is not equal to "twoSample", or if nPlan is of length(1) then ratio=1. |
parameter |
numeric, an optional savi test defining parameter. Default set to |
nMax |
integer > 0, maximum sample size of the (first) sample in each sample path. |
eType |
character one of "mom", "grow", "eGauss", and "eCauchy". "mom" is default and uses a non-local moment prior with bump(s) at meanDiffMin, "grow" uses point prior(s) at meanDiffMin, "eGauss" a zero-centred normal prior, "eCauchy" a zero centred Cauchy prior. |
wantEValuesAtNMax |
logical. If |
wantSamplePaths |
logical. If |
wantSimData |
logical. If |
pb |
logical, if |
seed |
integer, seed number. |
nSim |
integer > 0, the number of simulations needed to compute power or the number of samples paths for the savi z test under continuous monitoring. |
relevanceTest |
logical, if |
beta |
numerical in (0,1). Old parameter now replaced by the power parameter |
... |
further arguments to be passed to or from methods. |
meanDiffMin |
numeric that defines the minimal relevant mean difference, the smallest population mean difference that we would like to detect (with sufficient power). |
power |
numeric in (0, 1) that specifies the desired power, that is, the targetted chance to stop in favour of the alternative over the null hypothesis, when the alternative holds true. Note that prior to version 0.8.8 power <- 1-beta. The "beta" argument does not need to be specified anymore. |
relevanceSize |
numeric, the minimal clinical relevant mean difference that we do not want to miss under the alternative. Default relevanceSize=NULL implies relevanceSize=abs(meanDiffMin) |
alphaRelevance |
numeric, the threshold for relevance test. Taken to be minimum of alpha and 1-power. |
a list with stoppingTimes and breakVector. Entries of breakVector are 0, 1. A 1 represents stopping due to exceeding nMax, and 0 due to 1/alpha threshold crossing, which implies that in corresponding stopping time is Inf.
sampleStoppingTimesSafeZ(): Deprecated version of sampleStoppingTimesSaviZ
Grünwald, P. D., de Heide, R., & Koolen, W. (2024). Safe testing. Journal of the Royal Statistical Society. Series B (Methodological), 86(5), 1091-1128. (With discussions), https://doi.org/10.1093/jrsssb/qkae011. Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
sampleStoppingTimesSaviZ(0.7, nSim=10, nMax=20)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.