| setLowAndHighEsTrueZ | R Documentation |
Helper function to determine the lower and upper bound for the search space for standardised meanDiffMin
setLowAndHighEsTrueZ(
nEff,
eType = "mom",
alternative = "twoSided",
lowEsTrue = 1e-07,
highEsTrue = 0.001
)
nEff |
numeric > 0, the effective sample size. |
eType |
character string, one of "eCauchy", "eGauss", "grow", "freq", "credibleInterval". This is somewhat a misnomer as "freq" and "credibleInterval" do not correspond to e-value tests. "eCauchy" yields an anytime-valid confidence interval based on a Cauchy mixture, whereas "eGauss" yields an anytime-valid confidence interval based on a Gaussian mixture. "grow" yields an anytime-valid confidence interval based on a mixture of point masses at the minimal clinically relevant mean difference. This confidence interval unfortunately does not shrink as the sample size tends to infinity. "freq" yields the standard unsafe frequentist confidence interval, which is not safe. "credibleInterval" yields the Bayesian credible interval based on a conjugate prior as is usual in Bayesian analysis. This interval is also not safe. |
alternative |
a character string specifying the alternative hypothesis. Must be one of "twoSided" (default), "greater" or "less". |
lowEsTrue |
numeric, lower bound for the candidate set of the targeted minimal clinically relevant effect size for scenario 3.a. |
highEsTrue |
numeric, upper bound for the candidate set of the targeted minimal clinically relevant effect size for scenario 3.a. |
a list of low and high values for the parameter
setLowAndHighEsTrueZ(10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.