View source: R/newsafe2x2Test.R
| solveUmpLogOdds | R Documentation |
Solves the conditional KL divergence of the alternative at logOdds
from logOddsNull equal to log(1 / alpha), searching up to
searchBound from logOddsNull in the direction of alternative.
solveUmpLogOdds(
na,
nb,
totalSuccesses,
alpha,
alternative = c("greater", "less"),
logOddsNull = 0,
searchBound = 100
)
na |
number of observations in group A per data block, one value or one per block. |
nb |
number of observations in group B per data block, one value or one per block. |
totalSuccesses |
nonnegative integer, the total successes |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
alternative |
|
logOddsNull |
numeric, the null log odds ratio. |
searchBound |
numeric > 0, the width of the search interval. |
A numeric, or NULL with a warning when the target is not
reached on the search interval.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.