| tTestWidthDerivative | R Documentation |
Internal function to solve the smallest width of an eGauss t-test
tTestWidthDerivative(g, nEff, nu, alpha = 0.05)
g |
prior variance of the eGauss t-test |
nEff |
numeric > 0, the effective sample size. For one sample tests, this is just n. |
nu |
numeric > 0, the degrees of freedom. |
alpha |
numeric in (0, 1) that specifies the tolerable type I error and the null rejection rule e >= 1/alpha. |
a number that should be zero when g is optimal
Ly, A, Boehm, Grünwald, P. D., Ramdas, A., & van Ravenzwaaij, D. (2024). Safe Anytime-Valid Inference: Practical maximally flexible sampling designs for experiments based on e-values. PsyArXiv Preprint, https://doi.org/10.31234/osf.io/h5vae.
tTestWidthDerivative(1, 1, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.