| zMarg | R Documentation |
Logarithmic marginal likelihood of the normal with conjugate priors
zMarg(n, x, s2, a = 0, b = 1, sigma = 1)
n |
integer, sample size |
x |
numeric, sample mean |
s2 |
numeric > 0, sample variance |
a |
numeric, prior mean of the population mean mu |
b |
numeric > 0, prior standard deviation of the population mean mu |
sigma |
numeric > 0, population standard deviation |
numeric, the logarithm of the marginal likelihood
zMarg(12, 0.3, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.